﻿
-- PriorityList_Mainframe -> scrollframe -> content

local addonName, addonTable = ...
local L = addonTable.L

local mainframe_width = 500
local mainframe_height = 400
local scrollbar_width = 16
local border_size = 10
--local mainframe_bg = "Interface\\GLUES\\LoadingScreens\\LoadScreenBlackTemple"
local mainframe_bg = "Interface\\GLUES\\LoadingScreens\\LoadScreenBlizzcon2013wide"

CreateFont("PLButtonsFont")
PLButtonsFont:SetFont("Fonts\\ARIALN.ttf", 13, "")
PLButtonsFont:SetTextColor(0.5, 0.75, 1, 1)

local addon = PriorityList
addon.Constructors  = {}
addon.MenuFunctions = {}
addon.CharFunctions = {}
addon.ItemFunctions = {}
addon.CommFunctions = {}
addon.Serializer    = {}
addon.frames = {}

local constructors = addon.Constructors
local items = addon.ItemFunctions
local menus = addon.MenuFunctions

constructors.frame_backdrop = {
 bgFile = "Interface\\Buttons\\GreyscaleRamp64", 
 edgeFile = "Interface\\Buttons\\WHITE8X8", 
 edgeSize = 1
}

function constructors:SetupTexture(f, ...)
 f.tex = f:CreateTexture()
 f.tex:SetAllPoints()
 f.tex:SetTexture(...)
end

function constructors:SquareButton(name, p)
 local f = CreateFrame("Button", name, p)
 
 f:SetSize(50, 50)
 --f:SetNormalTexture("Interface\\spellbook\\GuildSpellbooktabIconFrame")
 f:SetHighlightTexture("Interface\\Buttons\\UI-Common-MouseHilight")
 f:SetNormalFontObject("PLButtonsFont")
 f:SetBackdrop(constructors.frame_backdrop)
 f:SetBackdropColor(0,0,0,0)
 f:SetBackdropBorderColor(0.1,0.3,0.4,1)

 return f 
end

function constructors:RectButton(...)
 local f = constructors:SquareButton(...)
 f:SetHighlightTexture("Interface\\PaperDollInfoFrame\\UI-Character-Tab-Highlight")
 return f
end

function constructors:PopupListBox(p, name, topleft_offsetx, topleft_offsety, bottomright_offsetx, bottomright_offsety, buttontype, updatefunc)
 local scrollframe = CreateFrame("ScrollFrame", name, p, "HybridScrollFrameTemplate") 
 scrollframe:SetFrameLevel(p:GetFrameLevel() + 1)
 scrollframe:EnableMouse(true)
 scrollframe:SetPoint("TOPLEFT", p, "TOPLEFT", topleft_offsetx, topleft_offsety)
 scrollframe:SetPoint("BOTTOMRIGHT", p, "BOTTOMRIGHT", bottomright_offsetx, bottomright_offsety)

 local scrollbar = CreateFrame("Slider", name.."ScrollBar", scrollframe, "HybridScrollBarTemplate")
 scrollbar:SetPoint("TOPLEFT", scrollframe, "TOPRIGHT", 4, -13)
 scrollbar:SetPoint("BOTTOMLEFT", scrollframe, "BOTTOMRIGHT", 4, 13)
 --scrollbar.doNotHide = true
 scrollframe.scrollBar = scrollbar

 HybridScrollFrame_CreateButtons(scrollframe, buttontype, 0, 0, "TOPLEFT", "TOPLEFT", 0, 0, "TOP", "BOTTOM")
 
 for i = 1, #(scrollframe.buttons) do
  scrollframe.buttons[i].index = i
  scrollframe.buttons[i]:SetScript("OnEnter", buttonOnEnter)
  scrollframe.buttons[i]:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
  scrollframe.buttons[i]:SetScript("OnMouseUp", function(self, ...) 
    local dd = scrollframe.dd
    if dd and dd.func then
	 menus:PopupHide()
	 dd.func(self.s_left:GetText())
	end
   end)
 end

 scrollframe.HideButtons = function(self)
  for i = 1, #self.buttons do
   self.buttons[i]:Hide()
  end
 end
 
 scrollframe.update = updatefunc
 scrollframe:SetScript("OnShow", function(self) self:update() end)

 scrollframe:SetScript("OnSizeChanged", function(self) 
  for i = 1,#(self.buttons) do
   self.buttons[i]:SetWidth(self:GetParent():GetWidth())
  end
 end)
 
 return scrollframe
end

function constructors:ListBox(p, name, topleft_offsetx, topleft_offsety, bottomright_offsetx, bottomright_offsety, buttontype, updatefunc, buttonOnClick, buttonOnEnter)
 local scrollframe = CreateFrame("ScrollFrame", name, p, "HybridScrollFrameTemplate") 
 constructors:SetupTexture(scrollframe, mainframe_bg)
 scrollframe:SetFrameLevel(p:GetFrameLevel() + 1)
 scrollframe:EnableMouse(true)
 scrollframe:SetPoint("TOPLEFT", p, "TOPLEFT", topleft_offsetx, topleft_offsety)
 scrollframe:SetPoint("BOTTOMRIGHT", p, "BOTTOMRIGHT", bottomright_offsetx, bottomright_offsety)

 local scrollbar = CreateFrame("Slider", name.."ScrollBar", scrollframe, "HybridScrollBarTemplate")
 scrollbar:SetPoint("TOPLEFT", scrollframe, "TOPRIGHT", 4, -13)
 scrollbar:SetPoint("BOTTOMLEFT", scrollframe, "BOTTOMRIGHT", 4, 13)
 scrollbar.doNotHide = true
 scrollframe.scrollBar = scrollbar

 HybridScrollFrame_CreateButtons(scrollframe, buttontype, 0, 0, "TOPLEFT", "TOPLEFT", 0, 0, "TOP", "BOTTOM")

 scrollframe:SetScript("OnReceiveDrag", function(...)
   local func = addon["listboxDragReceive"..addon.sel_tab]
   if func then func(...) end
  end)
  
 scrollframe:SetScript("OnMouseUp", function(...)
   local func = addon["listboxMouseUp"..addon.sel_tab]
   if func then func(...) end
  end)
 
 for i = 1, #(scrollframe.buttons) do
  --scrollframe.buttons[i]:SetWidth(scrollframe:GetWidth())
  scrollframe.buttons[i].func = buttonOnClick
  scrollframe.buttons[i].index = i
  scrollframe.buttons[i]:RegisterForDrag("LeftButton")
  scrollframe.buttons[i]:SetScript("OnDragStart", function(...)
   local func = addon["buttonDragStart"..addon.sel_tab]
   if func then func(...) end
  end)
  scrollframe.buttons[i]:SetScript("OnReceiveDrag", function(...)
   local func = addon["buttonDragReceive"..addon.sel_tab]
   if func then func(...) end
  end)
  scrollframe.buttons[i]:SetScript("OnMouseUp", function(...)
   local func = addon["buttonMouseUp"..addon.sel_tab]
   if func then func(...) end
  end)
  scrollframe.buttons[i]:SetScript("OnEnter", buttonOnEnter)
  scrollframe.buttons[i]:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
 end

 scrollframe.HideButtons = function(self)
  for i = 1, #self.buttons do
   self.buttons[i]:Hide()
  end
 end
 
 scrollframe.SetMode = function(self, mode)
  for i = 1,#(self.buttons) do
   if mode == "import" then
    self.buttons[i].lefticon:Show()
    self.buttons[i].s_topleft:Show()
    self.buttons[i].s_bottomleft:Show()
    self.buttons[i].s_topright:Show()
    self.buttons[i].s_bottomright:Show()
	self.buttons[i].s_center:Show()
    self.buttons[i].righticon:Show()
	self.buttons[i].centericon:Hide()
   else
    self.buttons[i].lefticon:Show()
    self.buttons[i].s_topleft:Show()
    self.buttons[i].s_bottomleft:Show()
    self.buttons[i].s_topright:Show()
    self.buttons[i].s_bottomright:Show()
	self.buttons[i].s_center:Show()
    self.buttons[i].righticon:Hide()
	self.buttons[i].centericon:Hide()
   end
  end
 end
 
 scrollframe.update = updatefunc

 scrollframe:SetScript("OnShow", function(self) self:update() end)

 scrollframe:SetScript("OnSizeChanged", function(self) 
  for i = 1,#(self.buttons) do
   self.buttons[i]:SetWidth(self:GetParent():GetWidth())
  end
 end)
 
 return scrollframe
end

-- simple index list dropdown
function constructors:DropDown(name, p)
 local f = constructors:RectButton(name, p)
 f:SetSize(150, 25)
 f.elements = {}
 f:SetScript("OnClick", function(self) menus.PopupShow(self) end)
 local arrow = f:CreateTexture()
 arrow:SetSize(24, 24)
 arrow:SetPoint("RIGHT", f, "RIGHT", -5, 0)
 arrow:SetTexture("Interface\\Buttons\\UI-MicroStream-Yellow")
 --local text = f:GetNormalFontObject()
 --text:SetJustifyH("CENTER")
 return f
end
--

local edt_counter = 1
function constructors:EditBox(p, title, func)
 local edt = CreateFrame("EditBox", "PLEditBox"..edt_counter, p)
 if title then
  edt.lbl = edt:CreateFontString()
  edt.lbl:SetFont("Fonts\\ARIALN.ttf", 11, "")
  edt.lbl:SetText(title) 
  edt.lbl:SetPoint("BOTTOMLEFT", edt, "TOPLEFT", 0, 0) 
 end
 edt:SetFontObject("GameFontHighlight")
 edt:SetWidth(100)
 edt:SetHeight(25)
 edt:SetBackdrop(GameTooltip:GetBackdrop())
 edt:SetBackdropColor(0, 0, 0, 0.8)
 edt:SetBackdropBorderColor(0.1,0.3,0.4,0.5)
 edt:SetTextInsets(10, 0, 0, 0)
 edt:SetAutoFocus(false)
 local f = function(self) self:ClearFocus() if func then func(self:GetText()) end end
 edt:SetScript("OnEnterPressed", f)
 edt:SetScript("OnEscapePressed", f)
 edt:ClearFocus()
 edt_counter = edt_counter + 1
 return edt
end

function constructors:Groupbox(p, name, w, h, text)
 local f = CreateFrame("Frame", name, p)
 f:SetSize(w,h)
 f:SetBackdrop(constructors.frame_backdrop)
 f:SetBackdropColor(0,0,0,0)
 f:SetBackdropBorderColor(0.1,0.3,0.4,0.5)
 if text and text ~= "" then
  f.text = f:CreateFontString()
  f.text:SetFont("Fonts\\ARIALN.ttf", 10, "")
  f.text:SetPoint("TOPLEFT", f, "TOPLEFT", 0, 10)
  f.text:SetText(text)
 end
 return f
end

-- slider
function constructors:Slider(p, name, text, minvalue, maxvalue, onValueChanged, ...)
 local f = CreateFrame("Slider", name, p, "OptionsSliderTemplate")
 f:SetSize(150,15)
 f:SetBackdrop(constructors.frame_backdrop)
 f:SetBackdropColor(0,0,0,1)
 f:SetBackdropBorderColor(0.2,0.2,0.2,1)

 local thumb = _G[name.."Thumb"]
 thumb:SetSize(16, 10)
 if ... then
  thumb:SetTexture(...)
 else
  thumb:SetTexture(0.3, 0.5, 0.8, 0.9)
 end
 
 f.lbl = f:CreateFontString(nil, "OVERLAY", "GameTooltipTextSmall")
 f.lbl:SetText(text)
 f.lbl:SetPoint("TOPLEFT", f, "TOPLEFT", -5, 10)

 f:SetOrientation("HORIZONTAL")
 f:SetMinMaxValues(minvalue, maxvalue)
 local lowtext = _G[name.."Low"]
 --lowtext:ClearAllPoints()
 --lowtext:SetPoint("BOTTOMLEFT", f, "BOTTOMLEFT", 0, -10)
 lowtext:SetText("")
 local hightext = _G[name.."High"]
 hightext:ClearAllPoints()
 hightext:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT", 0, -10)
 hightext:SetText(maxvalue)
 f.currenttext = hightext --f:CreateFontString(nil, "OVERLAY", "GameTooltipTextSmall")
 f:SetValueStep(0.1)
 f:SetValue(1)
 f.onValueChanged = onValueChanged
 f:SetScript("OnValueChanged", function(self, value) 
   local v = math.floor(value * 10) / 10
   self:SetValue(v)
   self.currenttext:SetText(v)
   if self.onValueChanged then self.onValueChanged(self, value) end
  end)
 return f
end

-- checkbox
local chkcounter = 0
function constructors:Checkbox(p, width, text)
 local f = CreateFrame("CheckButton", "PLOptCheckbox"..chkcounter, p, "OptionsCheckButtonTemplate")
 local txt = _G[f:GetName().."Text"]
 txt:SetWidth(width)
 txt:SetWordWrap(true)
 txt:SetText(text)
 f.title = txt
 local chk_tex = f:CreateTexture()
 chk_tex:SetTexture(0.3, 0.5, 0.8, 0.9)
 chk_tex:SetPoint("CENTER")
 chk_tex:SetSize(10,10)
 f:SetCheckedTexture(chk_tex)
 chkcounter = chkcounter + 1
 return f
end