-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...
local addon = PriorityList

local L = addonTable.L

local constructors = addon.Constructors
local items = addon.ItemFunctions
local menus = addon.MenuFunctions

local numTabs        = 8
addon.sel_tab        = 1
addon.sel_difficulty = 1
addon.sel_list       = 1

local function listButtonOnEnter(self)
 self:SetScript("OnEnter", function(self)
  if self.t == "item" and self.link then
   GameTooltip:SetOwner(self:GetParent(), "ANCHOR_RIGHT")
   GameTooltip:SetHyperlink(self.link)
   GameTooltip:Show()
  end
 end)
end

local function listboxUpdate(self)
 local func = addon["listboxUpdate"..addon.sel_tab]
 if func then func(self) end
end

local function selectDifficulty(i, no_refresh)
 addon.sel_difficulty = i
 for k = 1,3 do
  local btn = _G["PLBtnDifficulty"..k]
  if k == i then 
   btn:LockHighlight()
  else
   btn:UnlockHighlight()
  end
 end
 pl_options["last_difficulty"] = addon.sel_difficulty
 if not no_refresh then addon:Refresh() end
end

local function selectList(i, no_refresh)
 addon.sel_list = i
 for k = 1,3 do
  local btn = _G["PLWLBtnList"..k]
  if k == i then 
   btn:LockHighlight()
  else
   btn:UnlockHighlight()
  end
 end
 if not no_refresh then addon:Refresh() end
end

local function selectChar(name, no_refresh)
 
 if not PLWish_List[name] then
  addon.sel_char = ""
  if PLDDCharacters then 
   PLDDCharacters:SetText("") 
  end
  for k in pairs(PLWish_List) do
   selectChar(k)
   return
  end
  return
 end

 addon.sel_char = name

 if PLDDCharacters then
  PLDDCharacters:SetText(name)
 end
 if not no_refresh then addon:Refresh() end
end

function addon:Refresh()
 addon:GeneratePrio()
 if not PLMainframe or not PLMainframe:IsVisible() or not PLMainframe.listbox:IsVisible() then return end
 PLMainframe.listbox:update()
end

local function tabOnClick(self)
 menus:PopupHide()
 for i = 1,numTabs do
  local tab = _G["PLTab"..i]
  if tab == self then
   PanelTemplates_SelectTab(tab)
   _G["PLTabFrame"..i]:Show()
   addon.sel_tab = i
   PLMainframe.listbox:update()
  else
   PanelTemplates_DeselectTab(tab)
   _G["PLTabFrame"..i]:Hide()
  end
 end
 addon:Refresh()
end

function addon:EventPulse(event, ...)

 if     event == "select_char" then selectChar(...)
 elseif event == "select_list" then selectList(...) 
 elseif event == "select_difficulty" then selectDifficulty(...) 
 elseif event == "import_list" then 
  addon:Initialize(true)
  tabOnClick(PLTab5)
 end

 local func = addon["eventPulse"..addon.sel_tab]
 if func then func(event, ...) end
end

function addon:createMainframe()
 local f = CreateFrame("Frame", "PLMainframe", UIParent)
 f:SetSize(800,550)
 f:SetMinResize(800,300)
 f:SetPoint("CENTER")
 f:SetFrameStrata("HIGH")
 f:SetMovable(true)
 f:EnableMouse(true)
 --f:SetClampedToScreen(true)
 f:RegisterForDrag("LeftButton")
 local ondragstop = function() PLMainframe:StopMovingOrSizing() end
 f:SetScript("OnDragStart", function(self) self:StartMoving() end)
 f:SetScript("OnDragStop",  ondragstop)
 
 f.logo = f:CreateTexture()
 f.logo:SetPoint("TOP", f, "TOP", 0, -10)
 f.logo:SetSize(200,45)
 f.logo:SetTexture("Interface\\Addons\\PriorityList\\logo.tga")
 --[[ resize angle
 f.f_resize = CreateFrame("Frame", nil, f)
 f.f_resize:EnableMouse(true)
 f.f_resize:RegisterForDrag("LeftButton")
 f.f_resize:SetSize(25,25)
 f.f_resize:SetPoint("BOTTOMRIGHT")
 f.f_resize:SetScript("OnDragStart", function(self) PLMainframe:StartSizing() end)
 f.f_resize:SetScript("OnDragStop",  ondragstop)
 ]]--
 f.texture = f:CreateTexture()
 f.texture:SetPoint("TOPLEFT", f ,"TOPLEFT", 10, -10)
 f.texture:SetPoint("BOTTOMRIGHT", f ,"BOTTOMRIGHT", -10, 10)
 f.texture:SetTexture(0,0,0,1)
 f:SetBackdrop(constructors.frame_backdrop)
 f:SetBackdropColor(0,0,0,1)
 f:SetBackdropBorderColor(0.1,0.3,0.4,1)
 addon.frames.main = f
 
 menus:PopupInit(f)
 
 --[[ title
 f = PLMainframe:CreateFontString()
 f:SetFont("Fonts\\ARIALN.ttf", 16, "")
 f:SetPoint("TOP", PLMainframe, "TOP", 0, -15)
 f:SetText(addonName)]]
 
 -- difficulty buttons
 local function btndiff_onclick(self)
  local diff = string.gsub(self:GetName(), "PLBtnDifficulty", "")
  diff = tonumber(diff)
  addon:EventPulse("select_difficulty", diff)
  addon:Refresh()
 end
 
 -- normal
 f = constructors:SquareButton("PLBtnDifficulty1", PLMainframe)
 f:SetSize(50,35)
 f:SetPoint("TOPLEFT", PLMainframe, "TOPLEFT", 20, -20)
 f:SetText(L["difficulty1"])
 f:SetScript("OnClick", btndiff_onclick)
 -- heroic
 f = constructors:SquareButton("PLBtnDifficulty2", PLMainframe)
 f:SetSize(50,35)
 f:SetPoint("LEFT", PLBtnDifficulty1, "RIGHT", 10, 0)
 f:SetText(L["difficulty2"])
 f:SetScript("OnClick", btndiff_onclick)
 -- mythic
 f = constructors:SquareButton("PLBtnDifficulty3", PLMainframe)
 f:SetSize(50,35)
 f:SetPoint("LEFT", PLBtnDifficulty2, "RIGHT", 10, 0)
 f:SetText(L["difficulty3"])
 f:SetScript("OnClick", btndiff_onclick)

 -- close button
 f = constructors:SquareButton("PLClosebtn", PLMainframe)
 f:SetPoint("BOTTOM", PLMainframe, "BOTTOM", 0, 10)
 f:SetScript("OnClick", function() PLMainframe:Hide() end)
 f:SetSize(75,35)
 f:SetText(CLOSE)

 -- listbox
 f = constructors:ListBox(PLMainframe, "PLListbox", 30, -160, -50, 60, "PLListButtonTemplate", listboxUpdate, nil, listButtonOnEnter)
 --constructors:SetupTexture(f, pl_options["background"])
 f.tex:SetVertexColor(1,1,1,0.4)
 PLMainframe.listbox = f
 
 -- tab anchor
 f = constructors:Groupbox(PLMainframe, "PLMainframeTabAnchor", 1, 1)
 f:SetPoint("TOPLEFT", PLMainframe, "TOPLEFT", 29, -80)
 f:SetPoint("BOTTOMRIGHT", PLMainframe, "BOTTOMRIGHT", -49, 59)
 f:SetBackdropBorderColor(0.4,0.4,0.4,0.5)

 -- wishlist tab button
 f = CreateFrame("Button", "PLTab1", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("BOTTOMLEFT", PLMainframeTabAnchor, "TOPLEFT")
 f:SetScript("OnClick", tabOnClick)
 f:SetText(L["wishlist"])
 
 -- looted tab button
 f = CreateFrame("Button", "PLTab2", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("LEFT", PLTab1, "RIGHT", 5, 0)
 f:SetScript("OnClick", tabOnClick)
 f:SetText(L["looted"])
 
  -- itemslist tab button
 f = CreateFrame("Button", "PLTab3", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("LEFT", PLTab2, "RIGHT", 5, 0)
 f:SetScript("OnClick", tabOnClick)
 f:SetText(ITEMS)
 f:EnableMouse(false)

  -- bosslist tab button
 f = CreateFrame("Button", "PLTab4", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("LEFT", PLTab3, "RIGHT", 5, 0)
 f:SetScript("OnClick", tabOnClick)
 f:SetText(BOSS)
 f:EnableMouse(false)
 
 -- import tab button
 f = CreateFrame("Button", "PLTab5", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("LEFT", PLTab4, "RIGHT", 5, 0)
 f:SetScript("OnClick", tabOnClick)
 f:SetText(L["import"])
 
 -- messages tab button
 f = CreateFrame("Button", "PLTab6", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("LEFT", PLTab5, "RIGHT", 5, 0)
 f:SetScript("OnClick", tabOnClick)
 f:SetText(HISTORY)
 f:EnableMouse(false)

 -- options tab button
 f = CreateFrame("Button", "PLTab7", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("LEFT", PLTab6, "RIGHT", 5, 0)
 f:SetScript("OnClick", tabOnClick)
 f:SetText(GAMEOPTIONS_MENU)
 
 -- help tab button
 f = CreateFrame("Button", "PLTab8", PLMainframe, "OptionsFrameTabButtonTemplate")
 f:SetPoint("LEFT", PLTab7, "RIGHT", 5, 0)
 f:SetScript("OnClick", tabOnClick)
 f:SetText(GAMEMENU_HELP)
 f:EnableMouse(false)

 for i = 1,numTabs do
  addon["createTab"..i]()
 end
 
 addon:EventPulse("select_char", UnitName("player"), true)
 addon:EventPulse("select_list", 1, true)
 addon:EventPulse("select_difficulty", pl_options["last_difficulty"] or 1, true)
 tabOnClick(PLTab1)
 
 PLMainframe:Hide() -- tab buttons width acts weirdly on the first Show()
 PLMainframe:Show()
end