-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

-- tab 7

local tinsert = table.insert

local addonName, addonTable = ...
local L = addonTable.L
local C = addonTable.C

local addon = PriorityList
local comm = addon.CommFunctions
local wishlist = addon.WishListFunctions
local menus = addon.MenuFunctions
local items = addon.ItemFunctions
local chars = addon.CharFunctions
local constructors = addon.Constructors
local dialogs = addon.Dialogs

local SURadar = {}


local function onShow()
 if addon:IsSuperUser() then
  PLOptGrpSU.text:SetText(L["superuser"].." ("..addon.guildname..")")
  PLOptGrpVal:Show()
  PLOptGrpWish:Show()
  PLOptGrpSU:Show()
 else
  PLOptGrpVal:Hide()
  PLOptGrpWish:Hide()
  PLOptGrpSU:Hide()
 end
 PLListbox:Hide()
end

local function onHide()

end

function clearLists()
 local func = function() chars:ClearLists(addon.playername, addon.sel_difficulty) end
 dialogs:Confirm(func, true, string.format(L["confirm_wipe"], addon.playername, L["difficulty"..addon.sel_difficulty]))
end

function clearAllLists()
 local func = function() for k,v in pairs(PLWish_List) do chars:ClearLists(k, addon.sel_difficulty) end end
 dialogs:Confirm(func, true, string.format(L["confirm_wipe_all"], L["difficulty"..addon.sel_difficulty]))
end

function addon:SURadar_Add(name)
 if not tContains(SURadar, name) then
  tinsert(SURadar, name)
 end
end

function addon.createTab7()
 local chk_width = 220

 local f = CreateFrame("Frame", "PLTabFrame7", PLMainframe)
 f:SetPoint("TOPLEFT", PLMainframeTabAnchor, "TOPLEFT")
 f:SetPoint("BOTTOMRIGHT", PLMainframe, "BOTTOMRIGHT", -30, 60)
 f:SetScript("OnShow", onShow)
 f:SetScript("OnHide", onHide)
 
 ------- general --------
 local grp_general = constructors:Groupbox(PLTabFrame7, nil, 250, 180, GENERAL)
 grp_general:SetPoint("TOPLEFT", PLTabFrame7, "TOPLEFT", 20, -20)
 
 -- tooltip extension checkbox
 f = constructors:Checkbox(grp_general, chk_width, L["opt_ttextension"])
 f:SetPoint("TOPLEFT", grp_general, "TOPLEFT", 5, -2)
 f:SetChecked(pl_options["ttlinkbtn"])
 f:SetScript("OnClick", function(self)
  pl_options["ttlinkbtn"] = self:GetChecked() and true or false
 end)

 -- confirm changes checkbox
 f = constructors:Checkbox(grp_general, chk_width, L["opt_confirm"])
 f:SetPoint("TOPLEFT", grp_general, "TOPLEFT", 5, -22)
 f:SetChecked(pl_options["confirm_edit"])
 f:SetScript("OnClick", function(self)
  pl_options["confirm_edit"] = self:GetChecked() and true or false
 end)

 --[[ autosync checkbox
 f = constructors:Checkbox(grp_general, chk_width, L["autosync"])
 f:SetPoint("TOPLEFT", grp_general, "TOPLEFT", 5, -42)
 f:SetChecked(pl_options["autosync"])
 f:SetScript("OnClick", function(self)
  pl_options["autosync"] = self:GetChecked() and true or false
 end)
 ]]
 
 -- clear lists button
 f = constructors:RectButton("PLOptClearList", grp_general)
 f:SetPoint("BOTTOMLEFT", grp_general, "BOTTOMLEFT")
 f:SetSize(100,25)
 f:SetText(L["clearlists"])
 f:SetScript("OnClick", clearLists)
 
 -------------------------

 ------- wishlist --------
 local grp_wishlist = constructors:Groupbox(PLTabFrame7, "PLOptGrpWish", 250, 180, L["wishlist"])
 grp_wishlist:SetPoint("TOPLEFT", grp_general, "TOPRIGHT", 5, 0)

 -- short looted names checkbox
 f = constructors:Checkbox(grp_wishlist, chk_width, L["opt_shortnames"])
 f:SetPoint("TOPLEFT", grp_wishlist, "TOPLEFT", 5, -2)
 f:SetChecked(pl_options["short_looted_names"])
 f:SetScript("OnClick", function(self)
  pl_options["short_looted_names"] = self:GetChecked() and true or false
 end)
 
 -- show all chars checkbox
 f = constructors:Checkbox(grp_wishlist, chk_width, L["opt_showallchars"])
 f:SetPoint("TOPLEFT", grp_wishlist, "TOPLEFT", 5, -22)
 f:SetChecked(pl_options["show_all_chars"])
 f:SetScript("OnClick", function(self)
  pl_options["show_all_chars"] = self:GetChecked() and true or false
 end)
 
 -- clear ALL lists button
 f = constructors:RectButton("PLOptClearALLLists", grp_wishlist)
 f:SetPoint("BOTTOMLEFT", grp_wishlist, "BOTTOMLEFT")
 f:SetSize(100,25)
 f:SetText(L["clearALLlists"])
 f:SetScript("OnClick", clearAllLists)
 
 
 -------- values ---------
 local grp_values = constructors:Groupbox(PLTabFrame7, "PLOptGrpVal", 180, 180, L["bID_values"])
 grp_values:SetPoint("TOPLEFT", grp_wishlist, "TOPRIGHT", 5, 0)
 
 local function onValueChanged(self, value)
  local v = math.floor(value * 10) / 10
   self:SetValue(v)
   pl_options["bonus_value_"..self.tag] = v
 end
 
 for i = 1,C.numBonuses do
  if i > 2 then
   f = constructors:Slider(grp_values, "PLBonusSlider"..i, L["bonus"..i], 0, 1, onValueChanged, 1, 0.5, 0.3, 1)
  else
   f = constructors:Slider(grp_values, "PLBonusSlider"..i, L["bonus"..i], 0, 1, onValueChanged)
  end
  f:SetPoint("TOPLEFT", grp_values, "TOPLEFT", 15, -11 - (i - 1) * 35)
  f.tag = i
  f:SetValue(pl_options["bonus_value_"..i])
 end
 -------------------------
 
 ------- SuperUser --------
 local grp_su = constructors:Groupbox(PLTabFrame7, "PLOptGrpSU", 250, 180, L["superuser"])
 grp_su:SetPoint("TOPLEFT", grp_general, "BOTTOMLEFT", 0, -20)
 
 -- give SuperUser editbox
 f = constructors:EditBox(grp_su, L["opt_su_give"], comm.SetSuperUser)
 f:SetPoint("TOPLEFT", grp_su, "TOPLEFT", 5, -15)

 -- remove SuperUser editbox
 f = constructors:EditBox(grp_su, L["opt_su_remove"], comm.RemoveSuperUser)
 f:SetPoint("TOPLEFT", grp_su, "TOPLEFT", 5, -65)

 -- SuperUser radar
 f = constructors:RectButton("PL3OptSURadar", grp_su)
 f:SetPoint("TOPRIGHT", grp_su, "TOPRIGHT", -5, -5)
 f:SetText(L["radar"])
 f:SetScript("OnEnter", function(self)
  GameTooltip:SetOwner(self, "LEFT")
  GameTooltip:ClearLines()
  for k,v in pairs(SURadar) do
   GameTooltip:AddLine(v)
  end
  GameTooltip:Show()
 end)

 f:SetScript("OnLeave", function() GameTooltip:Hide() end)
 f:SetScript("OnClick", function() wipe(SURadar) comm:FindSuperUsers() end)
 
 PLTabFrame7:Hide()
 
 --[[
 f = constructors:RectButton("PL3TMPConvertButton", PLTabFrame7)
 f:SetPoint("BOTTOMRIGHT", PLMainframeTabAnchor, "BOTTOMRIGHT")
 f:SetSize(200,25)
 f:SetText("|cffFF0000<DEBUG>|r Importa liste da PL2")
 f:SetScript("OnClick", addon.ConvertPL2Lists)
 ]]
 
 --[[----- autosync ------
 local grp_sync = constructors:Groupbox(PLTabFrame7, nil, 180, 180, L["autosync"])
 grp_sync:SetPoint("TOPLEFT", grp_general, "TOPRIGHT", 5, 0)

 -- enable checkbox
 f = constructors:Checkbox(grp_sync, ENABLE)
 f:SetPoint("TOPLEFT", grp_sync, "TOPLEFT", 5, -2)
 f:SetChecked(pl_options["autosync"])
 f:SetScript("OnClick", function(self) 
  pl_options["autosync"] = self:GetChecked() and true or false
 end)
 
 -- officers
 for i = 1,3 do
  f = constructors:EditBox(grp_sync, "Officer "..i, function(self) pl_options["officer"..self.tag] = self:GetText() end)
  f.tag = i
  f:SetPoint("TOPLEFT", grp_sync, "TOPLEFT", 5, -45 * i - 5)
  f:SetWidth(150)
  f:SetText(pl_options["officer"..i] or "")
 end
 ]]-------------------------
 
 
 -- 3 o 4 editboxes per settare il nome degli officer e automatizzare
 -- sincronia (gli officer sincronizzano le liste dei vari pg)
 -- i pg comunicano loot personali 
end